#############################################################################################################
# PREAMBLE
#############################################################################################################

library(xlsx)       # read/write MS Excel
library(psych)      # linear correlation of parameters
library(vegan)      # permutational multivariate analysis of variance using distance matrices
library(metap)      # combining p-values
library(igraph)     # building and analyzing network models
library(paleotree)  # tree calibration
library(geoscale)   # plot trees
library(strap)      # plot trees
library(ape)        # phylogenetic analysis and tree manipulation
library(phytools)   # create phylomorphospaces and phenograms
library(geiger)     # disparity through time analysis
library(surface)    # evolutionary model estimation
library(mvMORPH)    # evolutionary model fitting
library(nlme)       # statistical tests
library(evomap)     # statistical tests in phy context
library(ggplot2)    # plot nicer, more output control
library(ggbiplot)   # plot PCA with ggplot2; require(devtools); install_github("vqv/ggbiplot")
library(GGally)     # plot networks with ggplot2 install.packages("GGally")
library(ggrepel)    # control label text within plot area
library(gridExtra)  # control multipanel

# Variables
networks<-c("Mus PECA","Didelphis PECA","Iguana PECA","Sphenodon PECA","Westlothiana PECA","Seymouria PECA","Ambystoma PECA","Salamandra PECA","Eryops PECA","Balanerpeton PECA","Tulerpeton PECA","Ichthyostega PECA","Acanthostega PECA","Tiktaalik PECA","Gogonasus PECA","Eusthenopteron PECA","Sauripterus PECA","Neoceratodus PECA","Latimeria PECA","Polypterus PECA","Mus PELA","Didelphis PELA","Iguana PELA","Sphenodon PELA","Westlothiana PELA","Seymouria PELA","Ambystoma PELA","Salamandra PELA","Eryops PELA","Balanerpeton PELA","Tulerpeton PELA","Ichthyostega PELA","Acanthostega PELA","Tiktaalik PELA","Gogonasus PELA","Eusthenopteron PELA","Sauripterus PELA","Neoceratodus PELA","Latimeria PELA","Polypterus PELA")
networks<-networks[-c(5,12,13,34,35,37)] # delete entry for which there is no good fossil data
parameter_names<-c("Nodes","Links","Density","Clustering","Path_length","Heterogeneity","Assortativity","Parcellation")
pec_index<-1:17  # taxa with pelctoral appendages in data
pel_index<-18:34 # taxa with pelvic appendages in data
pec_subsample_index<-pec_index[-c(11,12,14)] # taxa with pectoral & pelvic appendages in data
pel_subsample_index<-pel_index[-c(5,12,13)]

# Functions
# Wilcox test to evaluate modules
community.significance.test <- function(graph, vids, ...) {
  subgraph <- induced_subgraph(graph, vids)
  in.degrees <- igraph::degree(subgraph)
  out.degrees <- igraph::degree(graph, vids) - in.degrees
  w.test <- wilcox.test(in.degrees, out.degrees, alternative="greater")
  return(w.test)
}
# Jackknife of modularity Q value
jackknife_Q <- function(graph, membership){
  Qi <- vector()
  for (j in 1:ecount(graph)){
    g <- delete_edges(graph, j)
    Qi[j] <- modularity(g, membership)
  }
  ss <- sum((Qi-mean(Qi))^2)
  n <- (ecount(graph)-1)/ecount(graph)
  Q.error <- sqrt(n*ss)
  return(Q.error)
}
# Heterogeneity of connections (H)
heterogeneity <- function(graph){
  deg <- igraph::degree(graph)
  res <- sd(deg, na.rm=TRUE)/mean(deg, na.rm=FALSE)
  return(res)
}
# Parcellation index (P)
parcellation_index <- function(membership){
  Nm <- vector()
  for (i in 1:max(membership)){
    Nm[i] <- length(which(membership==i))
  }
  res <- 1-sum((Nm/length(membership))^2)
  return(res)
}

#############################################################################################################


#############################################################################################################
# MAKE NETWORK MODELS
#############################################################################################################

# Load data
mat.list<-mapply(read.xlsx,file="extended_adjacency_matrices.xlsx",sheetIndex=1:length(networks),check.names=FALSE)

# Prepare data
mat.list<-lapply(mat.list,function(x){x["NA"]<-NULL;x})
for (i in 1:length(networks)){max.dim<-dim(mat.list[[i]])[1]; mat.list[[i]]<-mat.list[[i]][,1:max.dim]}

# Create igraph objects in a list
adj.list<-lapply(mat.list,data.matrix,rownames.force=FALSE)
graph.list<-lapply(adj.list,graph_from_adjacency_matrix,mode="undirected")
graph.list<-lapply(graph.list,simplify) # make sure there are no loops and multi-links
names(graph.list) <- networks

#############################################################################################################


#############################################################################################################
# COMMUNITY DETECTION (TO CALCULATE P LATER)
#############################################################################################################

# Get communities
communities<-list()
start_time<-Sys.time() # control it does not take too much
for(i in 1:length(networks)){communities[[i]]<-cluster_optimal(graph.list[[i]])}
end_time<-Sys.time()
print(end_time-start_time) # checks how long it takes

# Get modularity global results
modules<-matrix(NA,nrow=length(networks),ncol=3)
for(i in 1:length(networks)){
  modules[i,1]<-length(communities[[i]])  # number of modules found
  modules[i,2]<-modularity(communities[[i]])  # value of the optimization parameter Q
  modules[i,3]<-jackknife_Q(graph.list[[i]],membership(communities[[i]]))  # expected error of the value Q
}
# save modularity
modules<-data.frame(modules, row.names=networks)
colnames(modules)<-c("Number of Modules","Q value","Q expected error")
write.xlsx(modules,file="extended_general/STable. Results optimal-modularity algorithm on extended networks.xlsx",sheetName="Sheet1")

# Get modularity details for each network
list.modules<-list()
for(i in 1:length(networks)){
  graph<-graph.list[[i]]
  community<-communities[[i]]
  mod.tab<-matrix(NA,nrow=length(community),ncol=3)
  colnames(mod.tab)<-c("Module number", "p-value","Nodes grouped")
  for(j in 1:length(community)){
    mod.tab[j,1]<-paste(j)
    mod.tab[j,2]<-round(community.significance.test(graph,vids=(membership(community)==j))$p.value,digits=5)
    mod.tab[j,3]<-paste(V(graph)$name[membership(community)==j],collapse=", ")
  }
  list.modules[[i]]<-mod.tab
}
# save details of specific modules
names(list.modules)<-networks
for(i in 1:length(networks)){ # sometimes fails to write all in one rund and need manual push of i
  modules2save<-data.frame(list.modules[[i]])
  write.xlsx(modules2save,file="extended_general/STables. Modules identified on extended networks.xlsx",sheetName=paste(networks[i]),append=TRUE,row.names=FALSE)
}

#############################################################################################################

#############################################################################################################
# MEASURE NETWORK PARAMETERS
#############################################################################################################

# Prepare output
parameters<-matrix(NA,nrow=length(networks),ncol=8)
rownames(parameters)<-networks
colnames(parameters)<-parameter_names

# Measure parameters  
parameters[,1]<-mapply(vcount,graph.list)
parameters[,2]<-mapply(ecount,graph.list)
parameters[,3]<-mapply(edge_density,graph.list)
parameters[,4]<-mapply(transitivity,graph.list,type="average",isolates="zero")
parameters[,5]<-mapply(mean_distance,graph.list,directed=FALSE)
parameters[,6]<-mapply(heterogeneity,graph.list)
parameters[,7]<-mapply(assortativity_degree,graph.list,directed=FALSE)
for(i in 1:length(networks)){parameters[i,8]<-parcellation_index(membership(communities[[i]]))}
parameters<-data.frame(parameters,row.names=networks)

# Save table raw parameters
write.xlsx(parameters, file="extended/Table 1. Network parameters of pectoral and pelvic appendages models (extended).xlsx", sheetName="Sheet1", row.names=TRUE)

# Transform count variables N and K for further analysis
parameters[,1]<-sqrt(parameters[,1])
parameters[,2]<-sqrt(parameters[,2])

# Correlation plot
svg(filename=paste("extended_general/SFigure. Distribution and correlations of network parameters (extended).svg"),width=10,height=10)
pairs.panels(parameters,lm=TRUE,hist.col="skyblue1")
dev.off()

# Divide pectoral and pelvic data  
pectoral_parameters<-parameters[pec_index,] # pectoral complete sample
pectoral_subsample_parameters<-parameters[pec_subsample_index,] # pectoral subsample: only with pelvic correspondence
pelvic_parameters<-parameters[pel_index,] # pelvic complete sample
pelvic_subsample_parameters<-parameters[pel_subsample_index,] # pelvic subsample: only with pectoral correspondence

#############################################################################################################


#############################################################################################################
# MAKE NICE PLOTS OF NETWORKS (OPTIONAL)
#############################################################################################################

library(network)    # alternative network objects (used only for plotting)
library(intergraph) # convert between alternative network objects
library(sna)        # alternative network objects

# Nodes clored by modules
for(i in 1:length(networks)){
  ig<-graph.list[[i]]
  ig<-ig%>%set_vertex_attr("degree",value=igraph::degree(ig))
  membership.label<-paste(communities[[i]]$membership," (p = ",round(as.numeric(list.modules[[i]][,2]),3)[communities[[i]]$membership],")",sep="")
  ig<-ig%>%set_vertex_attr("membership",value=membership.label)
  if(fin_limb[i]=="fin"){new_layout<-layout_with_fr(ig)  # try to adjust to the best layout for each type of appendage
  }else{new_layout<-layout_with_kk(ig)}
  net<-asNetwork(ig)
  p<-ggnet2(net,mode=new_layout,label=FALSE,color="membership",color.legend="Module (p-value)",color.palette="Set1",size="degree") +
    guides(size=FALSE) +
    geom_text_repel(label=network::get.vertex.attribute(net,"vertex.names"))
  # Save
  svg(filename=paste("extended_network_plots/",networks[i],"extended network plot with colored modules.svg"),width=10,height=7)
  print(p)
  dev.off()
}

# Nodes equally colored
for(i in 1:length(networks)){
  ig<-graph.list[[i]]
  ig<-ig%>%set_vertex_attr("degree",value=igraph::degree(ig))
  if(fin_limb[i]=="fin"){new_layout<-layout_with_fr(ig) # try to adjust to the best layout for each type of appendage
  }else{new_layout<-layout_with_kk(ig)}
  net<-asNetwork(ig)
  p<-ggnet2(net,mode=new_layout,edge.size=0.5,label=FALSE,color="#a68a56",show.legend=FALSE,size="degree") +
    guides(size=FALSE) +
    geom_text_repel(label=network::get.vertex.attribute(net,"vertex.names"),segment.alpha=0,color="#48608c")
  # Save
  svg(filename=paste("extended_network_plots/",networks[i],"extended network plot with colored modules.svg"),width=10,height=7)
  print(p)
  dev.off()
}

#############################################################################################################


#############################################################################################################
# TREE BUILDING
#############################################################################################################

# Input tree topology
tree_topology<-read.tree(text="(((((((((((((((Mus,Didelphis),(Iguana,Sphenodon)),Westlothiana),Seymouria),(((Ambystoma,Salamandra),Eryops),Balanerpeton)),Tulerpeton),Ichthyostega),Acanthostega),Tiktaalik),Gogonasus),Eusthenopteron),Sauripterus),Neoceratodus),Latimeria),Polypterus);")

# First and last appearance dates (FAD, LAD)
FAD_LAD<-matrix(ncol=2,byrow=TRUE,data=
                  c(73,0,        # Polypterus (TimeTree)
                    22,0,        # Latimeria (TimeTree)
                    28.4,0,      # Neoceratodus (TimeTree)
                    372.2,358.9, # Sauripterus (PaleoDB)
                    380,375,     # Eusthenopteron (PaleoDB)
                    384,380,     # Gogonasus (PaleoDB)
                    383.7,376.1, # Tiktaalik (PaleoDB)
                    376.1,360.7, # Acanthostega (PaleoDB)
                    376.1,360.7, # Ichthyostega (PaleoDB)
                    364.7,360.7, # Tulerpeton (PaleoDB)
                    336,326.4,   # Balanerpeton (PaleoDB)
                    303.4,272.5, # Eryops (PaleoDB)
                    12,0,        # Salamandra (TimeTree)
                    42,0,        # Ambystoma (TimeTree)
                    279.5,272.5, # Seymouria (PaleoDB)
                    336,326.4,   # Westlothiana (PaleoDB)
                    19,0,        # Sphenodon (TimeTree)
                    13,0,        # Iguana (TimeTree)
                    12,0,        # Didelphis (TimeTree)
                    10,0))       # Mus (TimeTree)
rownames(FAD_LAD)<-rev(tree_topology$tip.label)
colnames(FAD_LAD)<-c("FAD", "LAD")

# Set minimum dates for internal nodes (splits)
split_time<-rep(NA,tree_topology$Nnode)
split_time[1]<-419    # Actinopterygian-Sarcopterygian (Zhu et al. 2009)
split_time[2]<-416    # Actinistia-Rhipidistia (Swartz 2012)
split_time[3]<-408    # Dipnomorpha-Tetrapodomorpha (Benton et al. 2015)
split_time[11]<-330.4 # Batrachomorpha-Reptiliomorpha (Hedges & Kumar)
split_time[14]<-312.3 # Synapsida-Diapsida (Hedges & Kumar)
split_time[15]<-160   # Marsupialia-Placentalia (Luo et al. 2011)
split_time[16]<-238   # Rhynchocephalia-Squamata (Jones et al. 2013)
split_time[19]<-168   # Treptobranchia / Salamandroidea (Hedges & Kumar)

# Tree calibration using method 'equal' (Brusatte et al. 2008; Lloyd et al. 2012)
tree_calibrated<-timePaleoPhy(tree_topology,FAD_LAD,node.mins=split_time,type="equal",dateTreatment="firstLast",vartime=3,ntrees=1,add.term=T)

# Prepare trees
tree_pectoral<-drop.tip(phy=tree_calibrated,tip=c("Westlothiana","Acanthostega","Ichthyostega")) # remove taxa without pectoral appendages represented
tree_pelvic<-drop.tip(phy=tree_calibrated,tip=c("Tiktaalik","Gogonasus","Sauripterus")) # remove taxa without pelvic appendages represented
tree_pectoral_pelvic<-drop.tip(phy=tree_calibrated,tip=c("Westlothiana","Acanthostega","Ichthyostega","Tiktaalik","Gogonasus","Sauripterus")) # remove taxa without both appendages

# Save tree plot with the stratigraphical ranges included
svg(filename=paste("extended_general/Figure. Calibrated phylogeny.svg"),width=7,height=5)
geoscalePhylo(tree=tree_calibrated,ages=FAD_LAD,units=c("Period","Epoch"),boxes="Period",cex.age=0.5,cex.ts=0.45,cex.tip=0.5,quat.rm=T,x.lim=c(410,-20))
dev.off()

#############################################################################################################


#############################################################################################################
# SAVE NETWORK ANALYSIS WORKSPACE
#############################################################################################################

# Clean
rm(modules,list.modules,mod.tab,modules,end_time,start_time,graph,community,modules2save,mat.list,adj.list,i,j,split_time,ig,net,p,max.dim,start_time,end_time,graph,community,mod.tab,modules2save,new_layout,membership.label)

# Save
save.image("extended_networks_analysis_workspace.RData")

#############################################################################################################


#############################################################################################################
# ANALYSIS OF VARIANCE OF THE SAMPLE NETWORKS
#############################################################################################################

set.seed(73) # to get always same rotation + permanova

# Define grouping variables
pectoral_pelvic<-rep("pectoral",length(networks)); pectoral_pelvic[pel_index]<-"pelvic" # grouping variable pectoral vs pelvic
fin_limb<-rep("limb",length(networks)); fin_limb[c(11:17,31:34)]<-"fin" # grouping variable fin vs. limb
extinct_extant<-rep("extant",length(networks)); extinct_extant[c(5,8:14,22:23,26:31)]<-"extinct" # compargin extinct vs extant

# Compute PCA of all appendages
data<-parameters
pca_all<-prcomp(data,center=TRUE,scale.=TRUE) # centered in 0, scale=standarize variables because they have different units/ranges

# Save raw results
write.xlsx(data.frame(pca_all$x),file="extended/STable. PCA scores for complete sample (extended).xlsx",sheetName="Sheet1",row.names=TRUE) # print(all.pca)
write.xlsx(data.frame(summary(pca_all)$importance),file="extended/STable. Variance distribution across PCs for complete sample (extended).xlsx",sheetName="Sheet1",row.names=TRUE) # summary(all.pca)

# Prepare plots PC1 vs PC2
p1<-ggbiplot(pca_all,obs.scale=1,var.scale=1,ellipse=FALSE,alpha=0) +
  geom_text_repel(label=strtrim(networks,3),size=3,segment.color="gray50") +
  scale_shape_discrete(name=NULL) +
  geom_point(aes(shape=pectoral_pelvic),show.legend=NA) +
  theme_classic() +
  theme(legend.direction='horizontal',legend.position='top') +
  coord_fixed(xlim=c(-5,6.5),ylim=c(-5,6.5))

# PERMANOVA fins vs limbs
permapca<-adonis(pca_all$x~fin_limb,method='eu',permutations=10000) # same that using scale(parameters) ~ groups
test_text<-paste("F(",permapca$aov.tab$Df[1],",",permapca$aov.tab$Df[2],")"," = ",round(permapca$aov.tab$F.Model[1],3),", p = ",signif(permapca$aov.tab$Pr[1],4),sep="")
p2<-ggbiplot(pca_all,obs.scale=1,var.scale=1,ellipse=TRUE,ellipse.prob=0.68,groups=fin_limb,alpha=0) +
  scale_color_brewer(name='',type="div",palette="Set1") +
  theme_classic() +
  theme(legend.direction='horizontal',legend.position='top') +
  geom_point(aes(shape=factor(pectoral_pelvic),colour=factor(fin_limb)),show.legend=FALSE) +
  annotate("text",x=-2,y=5,label=test_text,hjust=0,size=3) +
  coord_fixed(xlim=c(-5,6.5),ylim=c(-5,6.5))

# PERMANOVA pectoral vs pelvic
permapca<-adonis(pca_all$x~pectoral_pelvic,method='eu',permutations=10000) # same that using scale(parameters) ~ groups
test_text<-paste("F(",permapca$aov.tab$Df[1],",",permapca$aov.tab$Df[2],")"," = ",round(permapca$aov.tab$F.Model[1],3),", p = ",signif(permapca$aov.tab$Pr[1],4),sep="")
p3<-ggbiplot(pca_all,obs.scale=1,var.scale=1,ellipse=TRUE,ellipse.prob=0.68,groups=pectoral_pelvic,alpha=0) +
  scale_color_brewer(name='',type="seq",palette="Set2",direction = -1) +
  theme_classic() +
  theme(legend.direction='horizontal',legend.position='top') +
  geom_point(aes(shape=factor(pectoral_pelvic),colour=factor(pectoral_pelvic)),show.legend=FALSE) +
  annotate("text",x=-2,y=5,label=test_text,hjust=0,size=3) +
  coord_fixed(xlim=c(-5,6.5),ylim=c(-5,6.5))

# PERMANOVA extinct vs extant
permapca<-adonis(pca_all$x~extinct_extant,method='eu',permutations=10000) # same that using scale(parameters) ~ groups
test_text<-paste("F(",permapca$aov.tab$Df[1],",",permapca$aov.tab$Df[2],")"," = ",round(permapca$aov.tab$F.Model[1],3),", p = ",signif(permapca$aov.tab$Pr[1],4),sep="")
p4<-ggbiplot(pca_all,obs.scale=1,var.scale=1,ellipse=TRUE,ellipse.prob=0.68,groups=extinct_extant,alpha=0) +
  scale_color_brewer(name='',type="div",palette="Dark2") +
  theme_classic() +
  theme(legend.direction='horizontal',legend.position='top') +
  geom_point(aes(shape=factor(pectoral_pelvic),colour=factor(extinct_extant)),show.legend=FALSE) +
  annotate("text",x=-2,y=5,label=test_text,hjust=0,size=3) +
  coord_fixed(xlim=c(-5,6.5),ylim=c(-5,6.5))

# Save plot (main Figure 2)
svg(filename=paste("extended/Figure 1. PCA of appendages topology (extended).svg"),width=7,height=7)
grid.arrange(arrangeGrob(p1,p2,ncol=2), # first row, 2 columns
             arrangeGrob(p3,p4,ncol=2), # second row, 2 columns
             nrow=2)                    # number of rows
dev.off()

# Check how much variation does each species account for
scores<-pca_all$x
explained_variation<-apply(scores,1,sd)^2/sum(apply(scores,1,sd)^2)
explained_variation<-as.data.frame(explained_variation,row.names=names(explained_variation))
write.xlsx(explained_variation,file="extended/STable. Explained variation of each network in PCA (extended).xlsx",sheetName="Sheet1",row.names=TRUE)

#############################################################################################################


#############################################################################################################
# EVOLUTIONARY ESTIMATION + MODEL FITTING
#############################################################################################################

##
## Pectoral complete sample
##
con<-file("extended/pectoral complete PC12.log")
sink(con, append=TRUE)
set.seed(73)

# Load data and tree
tree<-tree_pectoral
data<-pectoral_parameters
pca_data<-prcomp(data,center=TRUE,scale.=TRUE)
dat<-pca_data$x[,1:2]; rownames(dat)<-tree$tip.label

# SURFACE (Evolutionary estimation)
# prepare data and tree
tree<-treedata(tree,dat,sort=T,warnings=T)$phy #plot(tree); nodelabels()
dat<-as.data.frame(treedata(tree,dat,sort=TRUE)$data) #summary(dat)
tr<-nameNodes(tree)
olist<-convertTreeData(tr,dat)
otree<-olist[[1]]; odata<-olist[[2]]
# forward
fwd<-surfaceForward(otree,odata,aic_threshold=0,exclude=0,verbose=FALSE,plotaic=FALSE)
k<-length(fwd)
fsum<-surfaceSummary(fwd)
names(fsum)
fsum$aics
# backward
bwd<-surfaceBackward(otree,odata,starting_model=fwd[[k]],aic_threshold=0,only_best=FALSE,verbose=FALSE,plotaic=FALSE)
bsum<-surfaceSummary(bwd)
kk<-length(bwd)
# output
bsum$alpha
bsum$sigma_squared
bsum$theta
bsum$n_regimes
surfaceTreePlot(tr,bwd[[kk]],labelshifts=F,cex=0.5,edge.width=2,convcol=F,col=c("black","green","blue","cyan","orange","red"))
# signal
print("SIGNAL-TO-NOISE RATION (>1 GOOD)")
SNR_pectoral_complete_sample<-(sqrt(2*branching.times(tree)[[1]])*bsum$alpha*min(abs(bsum$theta)))/sqrt(bsum$sigma_squared)  
SNR_pectoral_complete_sample
surface_pectoral_complete_sample<-bwd

# Model fitting
dat<-as.matrix(dat)
# grouping (following SURFACE results)
Node_limbs<-findMRCA(tree,c("Mus","Gogonasus"))
# mapping estimated regimes
treemap<-paintSubTree(tree,node=Node_limbs,state=2,stem=TRUE)
# fitting models of evolution
Fit_BM1<-mvMORPH::mvBM(treemap,data=dat,error=NULL,model="BM1",control=list(maxit=100000))
Fit_BMM<-mvMORPH::mvBM(treemap,data=dat,error=NULL,model="BMM",control=list(maxit=100000))
Fit_OU1<-mvOU(treemap,data=dat,error=NULL,model="OU1",param=list(sigma="constraint",alpha="constraint"),control=list(maxit=100000)) # fixed rate, strength, mean optimal
Fit_OUMv<-mvOU(treemap,data=dat,error=NULL,model="OUM",param=list(alpha="constraint"),control=list(maxit=100000)) # fixed strength (changing rate and mean)
Fit_OUM<-mvOU(treemap,data=dat,error=NULL,model="OUM",param=list(sigma="constraint",alpha="constraint"),control=list(maxit=100000)) # fixed rate & strength mean (changing mean)
# comparing models
weights<-c(Fit_BM1$AICc,Fit_BMM$AICc,Fit_OU1$AICc,Fit_OUMv$AICc,Fit_OUM$AICc)
names(weights)<-c("BM 1-rate","BM multi-rate","OU 1-regime","OUM multi-sigma&mean","OUM multi-mean")
print("BEST MODEL FIT")
geiger::aicw(weights)

# Save output plots
svg("extended/SFigure. SURFACE pectoral complete PC12 tree (extended).svg")
tree_colors<-setNames(c("black","green"),1:2) 
plot(treemap,colors=tree_colors)
dev.off()

svg(filename=paste("extended/SFigure. SURFACE pectoral complete PC12 data (extended).svg"),width=7,height=7)
dat<-as.data.frame(dat,rownames(dat))
samp.names<-tree$tip.label
samp.data<-data.frame(samp=factor(samp.names,levels=samp.names,ordered=TRUE),value=dat$PC1)
p1<-ggplot(samp.data,aes(x=samp,y=value)) +
  geom_bar(stat="identity", position = "identity") +
  labs(x="",y="PC1") +
  theme(axis.ticks.y=element_blank(),axis.text.y=element_blank()) +
  scale_y_continuous(limits = c(-max(abs(samp.data$value)), max(abs(samp.data$value)))) +
  coord_flip()
samp.data<-data.frame(samp=factor(samp.names,levels=samp.names,ordered=TRUE),value=dat$PC2)
p2<-ggplot(samp.data,aes(x=samp,y=value)) +
  geom_bar(stat="identity", position = "identity") +
  labs(x="",y="PC2") +
  theme(axis.ticks.y=element_blank(),axis.text.y=element_blank()) +
  scale_y_continuous(limits = c(-max(abs(samp.data$value)), max(abs(samp.data$value)))) +
  coord_flip()
grid.arrange(arrangeGrob(p1,p2,ncol=2),nrow=1)
dev.off()

# Test the Ho that these groups are different phyloMANOVA
outree<-geiger::rescale(tree,model='OU',alpha=0.5)
lentree<-length(tree$tip.label)
A<-getDescendants(tree,Node_limbs)[getDescendants(tree,Node_limbs)<lentree]
grp<-rep(1,lentree)
grp[A]<-2
names(grp)<-tree$tip.label; grp<-as.factor(grp)
print("pMANOVA WITH OU-TREE")
aov.phylo(dat~grp,outree,nsim=10000,test="Wilks")
print("pMANOVA WITH BM-TREE")
aov.phylo(dat~grp,tree,nsim=10000,test="Wilks")
# test the fins-vs-limb groups
lentree<-length(tree$tip.label)
A<-getDescendants(tree,Node_limbs)[getDescendants(tree,Node_limbs)<lentree]
grp<-rep(1,lentree)
grp[A]<-2
names(grp)<-tree$tip.label; grp<-as.factor(grp)
print("pMANOVA WITH BM-TREE FIN-LIMB")
aov.phylo(dat~grp,tree,nsim=10000,test="Wilks")

sink() # closes the connection

##
## Pelvic complete sample
##
con <- file("extended/pelvic complete PC12.log")
sink(con, append=TRUE)
set.seed(73)

# Load data and tree
tree<-tree_pelvic
data<-pelvic_parameters
pca_data<-prcomp(data,center=TRUE,scale.=TRUE)
dat<-pca_data$x[,1:2]; rownames(dat)<-tree$tip.label

# SURFACE (Evolutionary estimation)
# prepare data and tree
tree<-treedata(tree,dat,sort=T,warnings=T)$phy
dat<-as.data.frame(treedata(tree,dat,sort=TRUE)$data)
tr<-nameNodes(tree)
olist<-convertTreeData(tr,dat)
otree<-olist[[1]]; odata<-olist[[2]]
# forward
fwd<-surfaceForward(otree,odata,aic_threshold=0,exclude=0,verbose=FALSE,plotaic=FALSE)
k<-length(fwd)
fsum<-surfaceSummary(fwd)
names(fsum)
fsum$aics
# backward
bwd<-surfaceBackward(otree,odata,starting_model=fwd[[k]],aic_threshold=0,only_best=FALSE,verbose=FALSE,plotaic=FALSE)
bsum<-surfaceSummary(bwd)
kk<-length(bwd)
# output
bsum$alpha
bsum$sigma_squared
bsum$theta
bsum$n_regimes
surfaceTreePlot(tr,bwd[[kk]],labelshifts=F,cex=0.5,edge.width=2,convcol=F,col=c("black","green","blue","cyan","orange","red"))
# signal
print("SIGNAL-TO-NOISE RATION (>1 GOOD)")
SNR_pelvic_complete_sample<-(sqrt(2*branching.times(tree)[[1]])*bsum$alpha*min(abs(bsum$theta)))/sqrt(bsum$sigma_squared)  
SNR_pelvic_complete_sample
surface_pelvic_complete_sample<-bwd

# Model fitting
dat<-as.matrix(dat)
# grouping (following SURFACE results)
Node_limbs<-findMRCA(tree,c("Mus","Acanthostega"))
Branch_latimeria<-which(tree$tip.label=="Latimeria")
Branch_neoceratodus<-which(tree$tip.label=="Neoceratodus")
# mapping estimated regimes
treemap<-paintSubTree(tree,node=Node_limbs,state=2,stem=TRUE)
treemap<-paintBranches(treemap,edge=Branch_latimeria,state=3)
treemap<-paintBranches(treemap,edge=Branch_neoceratodus,state=4)
# fitting models of evolution
Fit_BM1<-mvMORPH::mvBM(treemap,data=dat,error=NULL,model="BM1",control=list(maxit=100000))
Fit_BMM<-mvMORPH::mvBM(treemap,data=dat,error=NULL,model="BMM",control=list(maxit=100000))
Fit_OU1<-mvOU(treemap,data=dat,error=NULL,model="OU1",param=list(sigma="constraint",alpha="constraint"),control=list(maxit=100000)) # fixed rate, strength, mean optimal
Fit_OUMv<-mvOU(treemap,data=dat,error=NULL,model="OUM",param=list(alpha="constraint"),control=list(maxit=100000)) # fixed strength (changing rate and mean)
Fit_OUM<-mvOU(treemap,data=dat,error=NULL,model="OUM",param=list(sigma="constraint",alpha="constraint"),control=list(maxit=100000)) # fixed rate & strength mean (changing mean)
# comparing models
weights<-c(Fit_BM1$AICc,Fit_BMM$AICc,Fit_OU1$AICc,Fit_OUMv$AICc,Fit_OUM$AICc)
names(weights)<-c("BM 1-rate","BM multi-rate","OU 1-regime","OUM multi-sigma&mean","OUM multi-mean")
print("BEST MODEL FIT")
geiger::aicw(weights)

# Saving output plots
svg("extended/SFigure. SURFACE pelvic complete PC12 tree (extended).svg")
tree_colors<-setNames(c("black","green","cyan","blue"),1:4) 
plot(treemap,colors=tree_colors)
dev.off()

svg(filename=paste("extended/SFigure. SURFACE pelvic complete PC12 data (extended).svg"),width=7,height=7)
dat<-as.data.frame(dat,rownames(dat))
samp.names<-tree$tip.label
samp.data<-data.frame(samp=factor(samp.names,levels=samp.names,ordered=TRUE),value=dat$PC1)
p1<-ggplot(samp.data,aes(x=samp,y=value)) +
  geom_bar(stat="identity", position = "identity") +
  labs(x="",y="PC1") +
  theme(axis.ticks.y=element_blank(),axis.text.y=element_blank()) +
  scale_y_continuous(limits = c(-max(abs(samp.data$value)), max(abs(samp.data$value)))) +
  coord_flip()
samp.data<-data.frame(samp=factor(samp.names,levels=samp.names,ordered=TRUE),value=dat$PC2)
p2<-ggplot(samp.data,aes(x=samp,y=value)) +
  geom_bar(stat="identity", position = "identity") +
  labs(x="",y="PC2") +
  theme(axis.ticks.y=element_blank(),axis.text.y=element_blank()) +
  scale_y_continuous(limits = c(-max(abs(samp.data$value)), max(abs(samp.data$value)))) +
  coord_flip()
grid.arrange(arrangeGrob(p1,p2,ncol=2),nrow=1)
dev.off()

# Test the Ho that these groups are different phyloMANOVA
outree<-geiger::rescale(tree,model='OU',alpha=0.5)
lentree<-length(tree$tip.label)
A<-getDescendants(tree,Node_limbs)[getDescendants(tree,Node_limbs)<lentree]
B<-Branch_neoceratodus
C<-Branch_latimeria
grp<-rep(1,lentree)
grp[B]<-2
grp[C]<-3
grp[A]<-4
names(grp)<-tree$tip.label; grp<-as.factor(grp)
print("pMANOVA WITH OU-TREE")
aov.phylo(dat~grp,outree,nsim=10000,test="Wilks")
print("pMANOVA WITH BM-TREE")
aov.phylo(dat~grp,tree,nsim=10000,test="Wilks")
# Test the fins-vs-limb groups
lentree<-length(tree$tip.label)
A<-getDescendants(tree,Node_limbs)[getDescendants(tree,Node_limbs)<lentree]
grp<-rep(1,lentree)
grp[A]<-2
names(grp)<-tree$tip.label; grp<-as.factor(grp)
print("pMANOVA WITH BM-TREE FIN-LIMB")
aov.phylo(dat~grp,tree,nsim=10000,test="Wilks")

sink() # closes the connection

##
## Pectoral subsample
##
con <- file("extended/pectoral subsample PC12.log")
sink(con, append=TRUE)
set.seed(73)

# load data and tree
tree<-tree_pectoral_pelvic
data<-pectoral_subsample_parameters
pca_data<-prcomp(data,center=TRUE,scale.=TRUE)
dat<-pca_data$x[,1:2]; rownames(dat)<-tree$tip.label

# SURFACE (Evolutionary estimation)
# prepare data and tree
tree<-treedata(tree,dat,sort=T,warnings=T)$phy
dat<-as.data.frame(treedata(tree,dat,sort=TRUE)$data)
tr<-nameNodes(tree)
olist<-convertTreeData(tr,dat)
otree<-olist[[1]]; odata<-olist[[2]]
# forward
fwd<-surfaceForward(otree,odata,aic_threshold=0,exclude=0,verbose=FALSE,plotaic=FALSE)
k<-length(fwd)
fsum<-surfaceSummary(fwd)
names(fsum)
fsum$aics
# backward
bwd<-surfaceBackward(otree,odata,starting_model=fwd[[k]],aic_threshold=0,only_best=FALSE,verbose=FALSE,plotaic=FALSE)
bsum<-surfaceSummary(bwd)
kk<-length(bwd)
# output
bsum$alpha
bsum$sigma_squared
bsum$theta
bsum$n_regimes
surfaceTreePlot(tr,bwd[[kk]],labelshifts=F,cex=0.5,edge.width=2,convcol=F,col=c("black","green","blue","cyan","orange","red"))
# signal
print("SIGNAL-TO-NOISE RATION (>1 GOOD)")
SNR_pectoral_subsample<-(sqrt(2*branching.times(tree)[[1]])*bsum$alpha*min(abs(bsum$theta)))/sqrt(bsum$sigma_squared)  
SNR_pectoral_subsample
surface_pectoral_subsample<-bwd

# Model fitting
dat<-as.matrix(dat)
# grouping (following SURFACE results)
Node_limbs<-findMRCA(tree,c("Mus","Tulerpeton"))
# mapping estimated regimes
treemap<-paintSubTree(tree,node=Node_limbs,state=2,stem=TRUE)
# fitting models of evolution
Fit_BM1<-mvMORPH::mvBM(treemap,data=dat,error=NULL,model="BM1",control=list(maxit=100000))  #Note that you can include a standard error for within-species variation 
Fit_BMM<-mvMORPH::mvBM(treemap,data=dat,error=NULL,model="BMM",control=list(maxit=100000))
Fit_OU1<-mvOU(treemap,data=dat,error=NULL,model="OU1",param=list(sigma="constraint",alpha="constraint"),control=list(maxit=100000)) # fixed rate, strength, mean optimal
Fit_OUMv<-mvOU(treemap,data=dat,error=NULL,model="OUM",param=list(alpha="constraint"),control=list(maxit=100000)) # fixed strength (changing rate and mean)
Fit_OUM<-mvOU(treemap,data=dat,error=NULL,model="OUM",param=list(sigma="constraint",alpha="constraint"),control=list(maxit=100000)) # fixed rate & strength mean (changing mean)
# comparing models
weights<-c(Fit_BM1$AICc,Fit_BMM$AICc,Fit_OU1$AICc,Fit_OUMv$AICc,Fit_OUM$AICc)
names(weights)<-c("BM 1-rate","BM multi-rate","OU 1-regime","OUM multi-sigma&mean","OUM multi-mean")
print("BEST MODEL FIT")
geiger::aicw(weights)

# Saving output plots
svg("extended/SFigure. SURFACE pectoral subsample PC12 tree (extended).svg")
tree_colors<-setNames(c("black","green"),1:2) 
plot(treemap,colors=tree_colors)
dev.off()

svg(filename=paste("extended/SFigure. SURFACE pectoral subsample PC12 data (extended).svg"),width=7,height=7)
dat<-as.data.frame(dat,rownames(dat))
samp.names<-tree$tip.label
samp.data<-data.frame(samp=factor(samp.names,levels=samp.names,ordered=TRUE),value=dat$PC1)
p1<-ggplot(samp.data,aes(x=samp,y=value)) +
  geom_bar(stat="identity", position = "identity") +
  labs(x="",y="PC1") +
  theme(axis.ticks.y=element_blank(),axis.text.y=element_blank()) +
  scale_y_continuous(limits = c(-max(abs(samp.data$value)), max(abs(samp.data$value)))) +
  coord_flip()
samp.data<-data.frame(samp=factor(samp.names,levels=samp.names,ordered=TRUE),value=dat$PC2)
p2<-ggplot(samp.data,aes(x=samp,y=value)) +
  geom_bar(stat="identity", position = "identity") +
  labs(x="",y="PC2") +
  theme(axis.ticks.y=element_blank(),axis.text.y=element_blank()) +
  scale_y_continuous(limits = c(-max(abs(samp.data$value)), max(abs(samp.data$value)))) +
  coord_flip()
grid.arrange(arrangeGrob(p1,p2,ncol=2),nrow=1)
dev.off()

# Test the Ho that these groups are different phyloMANOVA
outree<-geiger::rescale(tree,model='OU',alpha=0.5)
lentree<-length(tree$tip.label)
A<-getDescendants(tree,Node_limbs)[getDescendants(tree,Node_limbs)<lentree]
grp<-rep(1,lentree)
grp[A]<-2
names(grp)<-tree$tip.label; grp<-as.factor(grp)
print("pMANOVA WITH OU-TREE")
aov.phylo(dat~grp,outree,nsim=10000,test="Wilks")
print("pMANOVA WITH BM-TREE")
aov.phylo(dat~grp,tree,nsim=10000,test="Wilks")
# Test the fins-vs-limb groups
Node_limbs<-findMRCA(tree,c("Mus","Tulerpeton"))
lentree<-length(tree$tip.label)
A<-getDescendants(tree,Node_limbs)[getDescendants(tree,Node_limbs)<lentree]
grp<-rep(1,lentree)
grp[A]<-2
names(grp)<-tree$tip.label; grp<-as.factor(grp)
print("pMANOVA WITH BM-TREE FIN-LIMB")
aov.phylo(dat~grp,tree,nsim=10000,test="Wilks")

sink() # closes the connection

##
## Pelvic subsample
##
con <- file("extended/pelvic subsample PC12.log")
sink(con, append=TRUE)
set.seed(73)

# load data and tree
tree<-tree_pectoral_pelvic
data<-pelvic_subsample_parameters
pca_data<-prcomp(data,center=TRUE,scale.=TRUE)
dat<-pca_data$x[,1:2]; rownames(dat)<-tree$tip.label

# SURFACE (Evolutionary estimation)
# prepare data and tree
tree<-treedata(tree,dat,sort=T,warnings=T)$phy
dat<-as.data.frame(treedata(tree,dat,sort=TRUE)$data)
tr<-nameNodes(tree)
olist<-convertTreeData(tr,dat)
otree<-olist[[1]]; odata<-olist[[2]]
# forward
fwd<-surfaceForward(otree,odata,aic_threshold=0,exclude=0,verbose=FALSE,plotaic=FALSE)
k<-length(fwd)
fsum<-surfaceSummary(fwd)
names(fsum)
fsum$aics
# backward
bwd<-surfaceBackward(otree,odata,starting_model=fwd[[k]],aic_threshold=0,only_best=FALSE,verbose=FALSE,plotaic=FALSE)
bsum<-surfaceSummary(bwd)
kk<-length(bwd)
# output
bsum$alpha
bsum$sigma_squared
bsum$theta
bsum$n_regimes
surfaceTreePlot(tr,bwd[[kk]],labelshifts=F,cex=0.5,edge.width=2,convcol=F,col=c("black","green","blue","cyan","orange","red"))
# signal
print("SIGNAL-TO-NOISE RATION (>1 GOOD)")
SNR_pelvic_subsample<-(sqrt(2*branching.times(tree)[[1]])*bsum$alpha*min(abs(bsum$theta)))/sqrt(bsum$sigma_squared)  
SNR_pelvic_subsample
surface_pelvic_subsample<-bwd

# Model fitting
dat<-as.matrix(dat)
# grouping (following SURFACE results)
Node_limbs<-findMRCA(tree,c("Mus","Tulerpeton"))
Branch_neoceratodus<-which(tree$tip.label=="Neoceratodus")
# mapping estimated regimes
treemap<-paintSubTree(tree,node=Node_limbs,state=2,stem=TRUE)
treemap<-paintBranches(treemap,edge=Branch_neoceratodus,state=3)
# fitting models of evolution
Fit_BM1<-mvMORPH::mvBM(treemap,data=dat,error=NULL,model="BM1",control=list(maxit=100000))  #Note that you can include a standard error for within-species variation 
Fit_BMM<-mvMORPH::mvBM(treemap,data=dat,error=NULL,model="BMM",control=list(maxit=100000))
Fit_OU1<-mvOU(treemap,data=dat,error=NULL,model="OU1",param=list(sigma="constraint",alpha="constraint"),control=list(maxit=100000)) # fixed rate, strength, mean optimal
Fit_OUMv<-mvOU(treemap,data=dat,error=NULL,model="OUM",param=list(alpha="constraint"),control=list(maxit=100000)) # fixed strength (changing rate and mean)
Fit_OUM<-mvOU(treemap,data=dat,error=NULL,model="OUM",param=list(sigma="constraint",alpha="constraint"),control=list(maxit=100000)) # fixed rate & strength mean (changing mean)
# comparing models
weights<-c(Fit_BM1$AICc,Fit_BMM$AICc,Fit_OU1$AICc,Fit_OUMv$AICc,Fit_OUM$AICc)
names(weights)<-c("BM 1-rate","BM multi-rate","OU 1-regime","OUM multi-sigma&mean","OUM multi-mean")
print("BEST MODEL FIT")
geiger::aicw(weights)

# Saving output plots
svg("extended/SFigure. SURFACE pelvic subsample PC12 tree (extended).svg")
tree_colors<-setNames(c("black","green","blue"),1:3) 
plot(treemap,colors=tree_colors)
dev.off()

svg(filename=paste("extended/SFigure. SURFACE pelvic subsample PC12 data (extended).svg"),width=7,height=7)
dat<-as.data.frame(dat,rownames(dat))
samp.names<-tree$tip.label
samp.data<-data.frame(samp=factor(samp.names,levels=samp.names,ordered=TRUE),value=dat$PC1)
p1<-ggplot(samp.data,aes(x=samp,y=value)) +
  geom_bar(stat="identity", position = "identity") +
  labs(x="",y="PC1") +
  theme(axis.ticks.y=element_blank(),axis.text.y=element_blank()) +
  scale_y_continuous(limits = c(-max(abs(samp.data$value)), max(abs(samp.data$value)))) +
  coord_flip()
samp.data<-data.frame(samp=factor(samp.names,levels=samp.names,ordered=TRUE),value=dat$PC2)
p2<-ggplot(samp.data,aes(x=samp,y=value)) +
  geom_bar(stat="identity", position = "identity") +
  labs(x="",y="PC2") +
  theme(axis.ticks.y=element_blank(),axis.text.y=element_blank()) +
  scale_y_continuous(limits = c(-max(abs(samp.data$value)), max(abs(samp.data$value)))) +
  coord_flip()
grid.arrange(arrangeGrob(p1,p2,ncol=2),nrow=1)
dev.off()

# Test the Ho that these groups are different phyloMANOVA
outree<-geiger::rescale(tree,model='OU',alpha=0.5)
lentree<-length(tree$tip.label)
A<-getDescendants(tree,Node_limbs)[getDescendants(tree,Node_limbs)<lentree]
B<-Branch_neoceratodus
grp<-rep(1,lentree)
grp[B]<-2
grp[A]<-3
names(grp)<-tree$tip.label; grp<-as.factor(grp)
print("pMANOVA WITH OU-TREE")
aov.phylo(dat~grp,outree,nsim=10000,test="Wilks")
print("pMANOVA WITH BM-TREE")
aov.phylo(dat~grp,tree,nsim=10000,test="Wilks")
# Test the fins-vs-limb groups
Node_limbs<-findMRCA(tree,c("Mus","Tulerpeton"))
lentree<-length(tree$tip.label)
A<-getDescendants(tree,Node_limbs)[getDescendants(tree,Node_limbs)<lentree]
grp<-rep(1,lentree)
grp[A]<-2
names(grp)<-tree$tip.label; grp<-as.factor(grp)
print("pMANOVA WITH BM-TREE FIN-LIMB")
aov.phylo(dat~grp,tree,nsim=10000,test="Wilks")

sink() # closes the connection

#############################################################################################################


#############################################################################################################
# DISPARITY TRHOUGH TIME
#############################################################################################################

##
## Pectoral complete sample
##
set.seed(73)

# Prepare data
data<-pectoral_parameters
tree<-tree_pectoral
pca_data<-prcomp(data,center=TRUE,scale.=TRUE)
dat<-pca_data$x; rownames(dat)<-tree$tip.label
tree<-treedata(tree,dat,sort=T,warnings=T)$phy
dat<-treedata(tree,dat,sort=T,warnings=T)$data

# DTT
disp<-dtt(tree,dat,index="avg.sq",nsim=10000,CI=0.95,plot=FALSE,calculateMDIp=T)
dtt_ma_time<-tree$root.time-(tree$root.time*disp$times)
dtt_sim_mean<-apply(disp$sim,1,mean)
dtt_sim_botCI<-dtt_sim_topCI<-vector()
for (i in 1:length(dtt_sim_mean)){
  dtt_sim_botCI[i]<-as.numeric(quantile(disp$sim[i,],0.025))
  dtt_sim_topCI[i]<-as.numeric(quantile(disp$sim[i,],0.975))
}
# output
output_dtt<-data.frame(cbind(dtt_ma_time,disp$dtt,dtt_sim_mean,dtt_sim_botCI,dtt_sim_topCI))
colnames(output_dtt)<-c("time","dtt","sim_mean","botci","topci")
# statistics
pvv<-vector()
intDTT<-disp$dtt
samDTT<-disp$sim
for (i in 1:length(intDTT)){
  x<-intDTT[i]
  sample<-sort(samDTT[i,],decreasing=TRUE)
  pvv[i]<-length(which(sample<=x))/length(sample)
}
test_text<-paste("Rand Inference",
                 "\n sim = 10,000",
                 "\n MDI =",round(disp$MDI,3),
                 "\n p =",formatC(sump(pvv)$p,format="e",digits=2))
# visualize
p<-ggplot(output_dtt,aes(x=time,y=dtt)) +
  geom_ribbon(aes(ymin=botci,ymax=topci),fill="grey90") +
  geom_line(size=1.25) +
  geom_line(aes(y=sim_mean),linetype="dotted",size=1) +
  theme_bw() + theme(panel.border=element_blank(),panel.grid.major=element_blank(),panel.grid.minor=element_blank(),axis.line=element_line(colour="black"),axis.text.x=element_text(size=10),axis.text.y=element_text(size=10)) +
  scale_x_reverse() +
  xlab("Time (Mya)") + ylab("Pectoral DTT (complete sample)") +
  geom_vline(xintercept=419,color="red",linetype="dashed") + # First sarcopterigyans Benton M.J. and Donoghue P.C.J. 2006
  annotate("text",x=417,y=2.5,label="Sarcopterygii",hjust=0,size=4) +
  geom_vline(xintercept=397,color="green",linetype="dashed") + # Zachelmie tracks (Niedzwiedzki et al. 2010)
  annotate("text",x=395,y=2.25,label="Zachelmie tracks",hjust=0,size=4) +
  geom_vline(xintercept=355,color="blue",linetype="dashed") + # Crown group tetrapoda (Clack et al 2016)
  annotate("text",x=353,y=2,label="Tetrapoda",hjust=0,size=4) +
  geom_vline(xintercept=312.3,color="red",linetype="dashed") + # First amniotes Benton M.J. and Donoghue P.C.J. 2006
  annotate("text",x=310,y=1.75,label="Amniota",hjust=0,size=4) +
  annotate("text",x=250,y=1.25,label=test_text,hjust=0,size=3.5)
dtt_pectoral_complete<-p

##
## Pectoral subsample
##
set.seed(73)

# Prepare data
data<-pectoral_subsample_parameters
tree<-tree_pectoral_pelvic
pca_data<-prcomp(data,center=TRUE,scale.=TRUE)
dat<-pca_data$x; rownames(dat)<-tree$tip.label
tree<-treedata(tree,dat,sort=T,warnings=T)$phy
dat<-treedata(tree,dat,sort=T,warnings=T)$data

# DTT
disp<-dtt(tree,dat,index="avg.sq",nsim=10000,CI=0.95,plot=FALSE,calculateMDIp=T)
dtt_ma_time<-tree$root.time-(tree$root.time*disp$times)
dtt_sim_mean<-apply(disp$sim,1,mean)
dtt_sim_botCI<-dtt_sim_topCI<-vector()
for (i in 1:length(dtt_sim_mean)){
  dtt_sim_botCI[i]<-as.numeric(quantile(disp$sim[i,],0.025))
  dtt_sim_topCI[i]<-as.numeric(quantile(disp$sim[i,],0.975))
}
# output
output_dtt<-data.frame(cbind(dtt_ma_time,disp$dtt,dtt_sim_mean,dtt_sim_botCI,dtt_sim_topCI))
colnames(output_dtt)<-c("time","dtt","sim_mean","botci","topci")
# statistics
pvv<-vector()
intDTT<-disp$dtt
samDTT<-disp$sim
for (i in 1:length(intDTT)){
  x<-intDTT[i]
  sample<-sort(samDTT[i,],decreasing=TRUE)
  pvv[i]<-length(which(sample<=x))/length(sample)
}
test_text<-paste("Rand Inference",
                 "\n sim = 10,000",
                 "\n MDI =",round(disp$MDI,3),
                 "\n p =",formatC(sump(pvv)$p,format="e",digits=2))
# visualize
p<-ggplot(output_dtt,aes(x=time,y=dtt)) +
  geom_ribbon(aes(ymin=botci,ymax=topci),fill="grey90") +
  geom_line(size=1.25) +
  geom_line(aes(y=sim_mean),linetype="dotted",size=1) +
  theme_bw() + theme(panel.border=element_blank(),panel.grid.major=element_blank(),panel.grid.minor=element_blank(),axis.line=element_line(colour="black"),axis.text.x=element_text(size=10),axis.text.y=element_text(size=10)) +
  scale_x_reverse() +
  xlab("Time (Mya)") + ylab("Pectoral DTT (subsample)") +
  geom_vline(xintercept=419,color="red",linetype="dashed") + # First sarcopterigyans Benton M.J. and Donoghue P.C.J. 2006
  annotate("text",x=417,y=2.5,label="Sarcopterygii",hjust=0,size=4) +
  geom_vline(xintercept=397,color="green",linetype="dashed") + # Zachelmie tracks (Niedzwiedzki et al. 2010)
  annotate("text",x=395,y=2.25,label="Zachelmie tracks",hjust=0,size=4) +
  geom_vline(xintercept=355,color="blue",linetype="dashed") + # Crown group tetrapoda (Clack et al 2016)
  annotate("text",x=353,y=2,label="Tetrapoda",hjust=0,size=4) +
  geom_vline(xintercept=312.3,color="red",linetype="dashed") + # First amniotes Benton M.J. and Donoghue P.C.J. 2006
  annotate("text",x=310,y=1.75,label="Amniota",hjust=0,size=4) +
  annotate("text",x=250,y=1.25,label=test_text,hjust=0,size=3.5)
dtt_pectoral_subsample<-p

##
## Pelvic complete sample
##
set.seed(73)

# Prepare data
data<-pelvic_parameters
tree<-tree_pelvic
pca_data<-prcomp(data,center=TRUE,scale.=TRUE)
dat<-pca_data$x; rownames(dat)<-tree$tip.label
tree<-treedata(tree,dat,sort=T,warnings=T)$phy
dat<-treedata(tree,dat,sort=T,warnings=T)$data

# DTT
disp<-dtt(tree,dat,index="avg.sq",nsim=10000,CI=0.95,plot=FALSE,calculateMDIp=T)
dtt_ma_time<-tree$root.time-(tree$root.time*disp$times)
dtt_sim_mean<-apply(disp$sim,1,mean)
dtt_sim_botCI<-dtt_sim_topCI<-vector()
for (i in 1:length(dtt_sim_mean)){
  dtt_sim_botCI[i]<-as.numeric(quantile(disp$sim[i,],0.025))
  dtt_sim_topCI[i]<-as.numeric(quantile(disp$sim[i,],0.975))
}
# output
output_dtt<-data.frame(cbind(dtt_ma_time,disp$dtt,dtt_sim_mean,dtt_sim_botCI,dtt_sim_topCI))
colnames(output_dtt)<-c("time","dtt","sim_mean","botci","topci")
# statistics
pvv<-vector()
intDTT<-disp$dtt
samDTT<-disp$sim
for (i in 1:length(intDTT)){
  x<-intDTT[i]
  sample<-sort(samDTT[i,],decreasing=TRUE)
  pvv[i]<-length(which(sample<=x))/length(sample)
}
test_text<-paste("Rand Inference",
                 "\n sim = 10,000",
                 "\n MDI =",round(disp$MDI,3),
                 "\n p =",formatC(sump(pvv)$p,format="e",digits=2))
# visualize
p<-ggplot(output_dtt,aes(x=time,y=dtt)) +
  geom_ribbon(aes(ymin=botci,ymax=topci),fill="grey90") +
  geom_line(size=1.25) +
  geom_line(aes(y=sim_mean),linetype="dotted",size=1) +
  theme_bw() + theme(panel.border=element_blank(),panel.grid.major=element_blank(),panel.grid.minor=element_blank(),axis.line=element_line(colour="black"),axis.text.x=element_text(size=10),axis.text.y=element_text(size=10)) +
  scale_x_reverse() +
  xlab("Time (Mya)") + ylab("Pelvic DTT (complete sample)") +
  geom_vline(xintercept=419,color="red",linetype="dashed") + # First sarcopterigyans Benton M.J. and Donoghue P.C.J. 2006
  annotate("text",x=417,y=2.5,label="Sarcopterygii",hjust=0,size=4) +
  geom_vline(xintercept=397,color="green",linetype="dashed") + # Zachelmie tracks (Niedzwiedzki et al. 2010)
  annotate("text",x=395,y=2.25,label="Zachelmie tracks",hjust=0,size=4) +
  geom_vline(xintercept=355,color="blue",linetype="dashed") + # Crown group tetrapoda (Clack et al 2016)
  annotate("text",x=353,y=2,label="Tetrapoda",hjust=0,size=4) +
  geom_vline(xintercept=312.3,color="red",linetype="dashed") + # First amniotes Benton M.J. and Donoghue P.C.J. 2006
  annotate("text",x=310,y=1.75,label="Amniota",hjust=0,size=4) +
  annotate("text",x=250,y=1.25,label=test_text,hjust=0,size=3.5)
dtt_pelvic_complete<-p

##
## Pelvic subsample
##
set.seed(73)

# Prerare data
data<-pelvic_subsample_parameters
tree<-tree_pectoral_pelvic
pca_data<-prcomp(data,center=TRUE,scale.=TRUE)
dat<-pca_data$x; rownames(dat)<-tree$tip.label
tree<-treedata(tree,dat,sort=T,warnings=T)$phy
dat<-treedata(tree,dat,sort=T,warnings=T)$data

# DTT
disp<-dtt(tree,dat,index="avg.sq",nsim=10000,CI=0.95,plot=FALSE,calculateMDIp=T)
dtt_ma_time<-tree$root.time-(tree$root.time*disp$times)
dtt_sim_mean<-apply(disp$sim,1,mean)
dtt_sim_botCI<-dtt_sim_topCI<-vector()
for (i in 1:length(dtt_sim_mean)){
  dtt_sim_botCI[i]<-as.numeric(quantile(disp$sim[i,],0.025))
  dtt_sim_topCI[i]<-as.numeric(quantile(disp$sim[i,],0.975))
}
# output
output_dtt<-data.frame(cbind(dtt_ma_time,disp$dtt,dtt_sim_mean,dtt_sim_botCI,dtt_sim_topCI))
colnames(output_dtt)<-c("time","dtt","sim_mean","botci","topci")
# statistics
pvv<-vector()
intDTT<-disp$dtt
samDTT<-disp$sim
for (i in 1:length(intDTT)){
  x<-intDTT[i]
  sample<-sort(samDTT[i,],decreasing=TRUE)
  pvv[i]<-length(which(sample<=x))/length(sample)
}
test_text<-paste("Rand Inference",
                 "\n sim = 10,000",
                 "\n MDI =",round(disp$MDI,3),
                 "\n p =",formatC(sump(pvv)$p,format="e",digits=2))
# visualize
p<-ggplot(output_dtt,aes(x=time,y=dtt)) +
  geom_ribbon(aes(ymin=botci,ymax=topci),fill="grey90") +
  geom_line(size=1.25) +
  geom_line(aes(y=sim_mean),linetype="dotted",size=1) +
  theme_bw() + theme(panel.border=element_blank(),panel.grid.major=element_blank(),panel.grid.minor=element_blank(),axis.line=element_line(colour="black"),axis.text.x=element_text(size=10),axis.text.y=element_text(size=10)) +
  scale_x_reverse() +
  xlab("Time (Mya)") + ylab("Pelvic DTT (subsample)") +
  geom_vline(xintercept=419,color="red",linetype="dashed") + # First sarcopterigyans Benton M.J. and Donoghue P.C.J. 2006
  annotate("text",x=417,y=2.5,label="Sarcopterygii",hjust=0,size=4) +
  geom_vline(xintercept=397,color="green",linetype="dashed") + # Zachelmie tracks (Niedzwiedzki et al. 2010)
  annotate("text",x=395,y=2.25,label="Zachelmie tracks",hjust=0,size=4) +
  geom_vline(xintercept=355,color="blue",linetype="dashed") + # Crown group tetrapoda (Clack et al 2016)
  annotate("text",x=353,y=2,label="Tetrapoda",hjust=0,size=4) +
  geom_vline(xintercept=312.3,color="red",linetype="dashed") + # First amniotes Benton M.J. and Donoghue P.C.J. 2006
  annotate("text",x=310,y=1.75,label="Amniota",hjust=0,size=4) +
  annotate("text",x=250,y=1.25,label=test_text,hjust=0,size=3.5)
dtt_pelvic_subsample<-p

# Save figures
svg(filename=paste("extended/Figure 4. Disparity through time of pectoral and pelvic appendages(extended).svg"),width=8,height=8)
grid.arrange(arrangeGrob(dtt_pectoral_complete,dtt_pelvic_complete,ncol=2), # first row, 2 columns
             arrangeGrob(dtt_pectoral_subsample,dtt_pelvic_subsample,ncol=2), # second row, 2 columns
             nrow=2)                    # number of rows
dev.off()

#############################################################################################################


#############################################################################################################
# COMPARING PECTORAL AND PELVIC: PECTORAL-PELVIC SIMILARITY BOTTLENECKS
#############################################################################################################

# Prepare data
set.seed(73)
col<-c(rep("black",13),"blue")
tree<-tree_pectoral_pelvic
# get distance from bottleneck in absolute time
tetrapoda_time<-branching.times(tree)[findMRCA(tree,c("Tulerpeton","Mus"))-length(tree$tip.label)]
tips_time<-rev(FAD_LAD[row.names(FAD_LAD)%in%tree$tip.label,1])
# hypothesis
time_from_bottleneck<-abs(tetrapoda_time-tips_time)

## Nodes
variable<-"Nodes"
y<-pectoral_subsample_parameters[,which(parameter_names==variable)]
x<-pelvic_subsample_parameters[,which(parameter_names==variable)]
# get residulas for the identity line
a=1;b=-1;c=0
xi = (b*(b*x-a*y)-a*c) / (a^2+b^2)
yi = (a*(-b*x+a*y)-b*c) / (a^2+b^2)
y.res<-abs(a*x+b*y+c)/sqrt(a^2+b^2) # calculate absolute residuals
y.res<-(y.res-min(y.res))/(max(y.res)-min(y.res)) # normalization (from 0 to 1)
# test fin-bearing vs limb-bearing taxa y.res
print(variable)
grp<-as.factor(c(rep(1,10),rep(2,4)))
names(y.res)<-names(grp)<-tre<-tree$tip.label 
aov.phylo(y.res~grp, tree)
# test residuals~time agree with bottleneck
df<-as.data.frame(cbind(y.res,time_from_bottleneck),row.names=tree$tip.label)
pgls<-gls(y.res[-14]~time_from_bottleneck[-14],df[-14,],corPagel(1,phy=drop.tip(tree,14)))
# plot result
test_text<-paste(variable,
                 "\n Ho: slope = 0",
                 "\n slope =",formatC(summary(pgls)$tTable[2,1],format="e",digits=2),
                 "\n SE =",formatC(summary(pgls)$tTable[2,2],format="e",digits=2),
                 "\n t =",formatC(summary(pgls)$tTable[2,2],format="e",digits=2),
                 "\n p-value =",round(summary(pgls)$tTable[2,4],3))
pN<-ggplot(df, aes(time_from_bottleneck,y.res)) +
  geom_abline(intercept=pgls$coefficients[1],slope=pgls$coefficients[2],color="red",size=1) +
  geom_point(size=1.5,color=col) +
  theme_bw() + theme(axis.line=element_line(colour="black"),axis.text.x=element_text(size=10),axis.text.y=element_text(size=10)) +
  xlab("") + ylab("Pectoral-Pelvic Disparity") +
  annotate("text",x=100,y=0.8,label=test_text,hjust=0,size=3)

## Links
variable<-"Links"
y<-pectoral_subsample_parameters[,which(parameter_names==variable)]
x<-pelvic_subsample_parameters[,which(parameter_names==variable)]
# get residulas for the identity line
a=1;b=-1;c=0
xi = (b*(b*x-a*y)-a*c) / (a^2+b^2)
yi = (a*(-b*x+a*y)-b*c) / (a^2+b^2)
y.res<-abs(a*x+b*y+c)/sqrt(a^2+b^2)
y.res<-(y.res-min(y.res))/(max(y.res)-min(y.res)) # normalization (from 0 to 1)
# test fin-bearing vs limb-bearing taxa y.res
print(variable)
grp<-as.factor(c(rep(1,10),rep(2,4)))
names(y.res)<-names(grp)<-tre<-tree$tip.label 
aov.phylo(y.res~grp, tree)
# test residuals~time agree with bottleneck
df<-as.data.frame(cbind(y.res,time_from_bottleneck),row.names=tree$tip.label)
pgls<-gls(y.res[-14]~time_from_bottleneck[-14],df[-14,],corPagel(1,phy=drop.tip(tree,14)))
# plot result
test_text<-paste(variable,
                 "\n Ho: slope = 0",
                 "\n slope =",formatC(summary(pgls)$tTable[2,1],format="e",digits=2),
                 "\n SE =",formatC(summary(pgls)$tTable[2,2],format="e",digits=2),
                 "\n t =",formatC(summary(pgls)$tTable[2,2],format="e",digits=2),
                 "\n p-value =",round(summary(pgls)$tTable[2,4],3))
pK<-ggplot(df, aes(time_from_bottleneck,y.res)) +
  geom_abline(intercept=pgls$coefficients[1],slope=pgls$coefficients[2],color="red",size=1) +
  geom_point(size=1.5,color=col) +
  theme_bw() + theme(axis.line=element_line(colour="black"),axis.text.x=element_text(size=10),axis.text.y=element_text(size=10)) +
  xlab("") + ylab("") +
  annotate("text",x=100,y=0.8,label=test_text,hjust=0,size=3)

## Density
variable<-"Density"
y<-pectoral_subsample_parameters[,which(parameter_names==variable)]
x<-pelvic_subsample_parameters[,which(parameter_names==variable)]
# get residulas for the identity line
a=1;b=-1;c=0
xi = (b*(b*x-a*y)-a*c) / (a^2+b^2)
yi = (a*(-b*x+a*y)-b*c) / (a^2+b^2)
y.res<-abs(a*x+b*y+c)/sqrt(a^2+b^2)
y.res<-(y.res-min(y.res))/(max(y.res)-min(y.res)) # normalization (from 0 to 1)
# test fin-bearing vs limb-bearing taxa y.res
print(variable)
grp<-as.factor(c(rep(1,10),rep(2,4)))
names(y.res)<-names(grp)<-tre<-tree$tip.label 
aov.phylo(y.res~grp, tree)
# test residuals~time agree with bottleneck
df<-as.data.frame(cbind(y.res,time_from_bottleneck),row.names=tree$tip.label)
pgls<-gls(y.res[-14]~time_from_bottleneck[-14],df[-14,],corPagel(1,phy=drop.tip(tree,14)))
# plot result
test_text<-paste(variable,
                 "\n Ho: slope = 0",
                 "\n slope =",formatC(summary(pgls)$tTable[2,1],format="e",digits=2),
                 "\n SE =",formatC(summary(pgls)$tTable[2,2],format="e",digits=2),
                 "\n t =",formatC(summary(pgls)$tTable[2,2],format="e",digits=2),
                 "\n p-value =",round(summary(pgls)$tTable[2,4],3))
pD<-ggplot(df, aes(time_from_bottleneck,y.res)) +
  geom_abline(intercept=pgls$coefficients[1],slope=pgls$coefficients[2],color="red",size=1) +
  geom_point(size=1.5,color=col) +
  theme_bw() + theme(axis.line=element_line(colour="black"),axis.text.x=element_text(size=10),axis.text.y=element_text(size=10)) +
  xlab("") + ylab("") +
  annotate("text",x=100,y=0.8,label=test_text,hjust=0,size=3)

## Clustering
variable<-"Clustering"
y<-pectoral_subsample_parameters[,which(parameter_names==variable)]
x<-pelvic_subsample_parameters[,which(parameter_names==variable)]
# get residulas for the identity line
a=1;b=-1;c=0
xi = (b*(b*x-a*y)-a*c) / (a^2+b^2)
yi = (a*(-b*x+a*y)-b*c) / (a^2+b^2)
y.res<-abs(a*x+b*y+c)/sqrt(a^2+b^2)
y.res<-(y.res-min(y.res))/(max(y.res)-min(y.res)) # normalization (from 0 to 1)
# test fin-bearing vs limb-bearing taxa y.res
print(variable)
grp<-as.factor(c(rep(1,10),rep(2,4)))
names(y.res)<-names(grp)<-tre<-tree$tip.label 
aov.phylo(y.res~grp, tree)
# test residuals~time agree with bottleneck
df<-as.data.frame(cbind(y.res,time_from_bottleneck),row.names=tree$tip.label)
pgls<-gls(y.res[-14]~time_from_bottleneck[-14],df[-14,],corPagel(1,phy=drop.tip(tree,14)))
# plot result
test_text<-paste(variable,
                 "\n Ho: slope = 0",
                 "\n slope =",formatC(summary(pgls)$tTable[2,1],format="e",digits=2),
                 "\n SE =",formatC(summary(pgls)$tTable[2,2],format="e",digits=2),
                 "\n t =",formatC(summary(pgls)$tTable[2,2],format="e",digits=2),
                 "\n p-value =",round(summary(pgls)$tTable[2,4],3))
pC<-ggplot(df, aes(time_from_bottleneck,y.res)) +
  geom_abline(intercept=pgls$coefficients[1],slope=pgls$coefficients[2],color="red",size=1) +
  geom_point(size=1.5,color=col) +
  theme_bw() + theme(axis.line=element_line(colour="black"),axis.text.x=element_text(size=10),axis.text.y=element_text(size=10)) +
  xlab("") + ylab("") +
  annotate("text",x=100,y=0.8,label=test_text,hjust=0,size=3)

## Path_length
variable<-"Path_length"
y<-pectoral_subsample_parameters[,which(parameter_names==variable)]
x<-pelvic_subsample_parameters[,which(parameter_names==variable)]
# get residulas for the identity line
a=1;b=-1;c=0
xi = (b*(b*x-a*y)-a*c) / (a^2+b^2)
yi = (a*(-b*x+a*y)-b*c) / (a^2+b^2)
y.res<-abs(a*x+b*y+c)/sqrt(a^2+b^2)
y.res<-(y.res-min(y.res))/(max(y.res)-min(y.res)) # normalization (from 0 to 1)
# test fin-bearing vs limb-bearing taxa y.res
print(variable)
grp<-as.factor(c(rep(1,10),rep(2,4)))
names(y.res)<-names(grp)<-tre<-tree$tip.label 
aov.phylo(y.res~grp, tree)
# test residuals~time agree with bottleneck
df<-as.data.frame(cbind(y.res,time_from_bottleneck),row.names=tree$tip.label)
pgls<-gls(y.res[-14]~time_from_bottleneck[-14],df[-14,],corPagel(1,phy=drop.tip(tree,14)))
# plot result
test_text<-paste(variable,
                 "\n Ho: slope = 0",
                 "\n slope =",formatC(summary(pgls)$tTable[2,1],format="e",digits=2),
                 "\n SE =",formatC(summary(pgls)$tTable[2,2],format="e",digits=2),
                 "\n t =",formatC(summary(pgls)$tTable[2,2],format="e",digits=2),
                 "\n p-value =",round(summary(pgls)$tTable[2,4],3))
pL<-ggplot(df, aes(time_from_bottleneck,y.res)) +
  geom_abline(intercept=pgls$coefficients[1],slope=pgls$coefficients[2],color="red",size=1) +
  geom_point(size=1.5,color=col) +
  theme_bw() + theme(axis.line=element_line(colour="black"),axis.text.x=element_text(size=10),axis.text.y=element_text(size=10)) +
  xlab("Time from Tetrapoda Bottleneck (My)") + ylab("Pectoral-Pelvic Disparity") +
  annotate("text",x=100,y=0.8,label=test_text,hjust=0,size=3)

## Heterogeneity
variable<-"Heterogeneity"
y<-pectoral_subsample_parameters[,which(parameter_names==variable)]
x<-pelvic_subsample_parameters[,which(parameter_names==variable)]
# get residulas for the identity line
a=1;b=-1;c=0
xi = (b*(b*x-a*y)-a*c) / (a^2+b^2)
yi = (a*(-b*x+a*y)-b*c) / (a^2+b^2)
y.res<-abs(a*x+b*y+c)/sqrt(a^2+b^2)
y.res<-(y.res-min(y.res))/(max(y.res)-min(y.res)) # normalization (from 0 to 1)
# test fin-bearing vs limb-bearing taxa y.res
print(variable)
grp<-as.factor(c(rep(1,10),rep(2,4)))
names(y.res)<-names(grp)<-tre<-tree$tip.label 
aov.phylo(y.res~grp, tree)
# test residuals~time agree with bottleneck
df<-as.data.frame(cbind(y.res,time_from_bottleneck),row.names=tree$tip.label)
pgls<-gls(y.res[-14]~time_from_bottleneck[-14],df[-14,],corPagel(1,phy=drop.tip(tree,14)))
# plot result
test_text<-paste(variable,
                 "\n Ho: slope = 0",
                 "\n slope =",formatC(summary(pgls)$tTable[2,1],format="e",digits=2),
                 "\n SE =",formatC(summary(pgls)$tTable[2,2],format="e",digits=2),
                 "\n t =",formatC(summary(pgls)$tTable[2,2],format="e",digits=2),
                 "\n p-value =",round(summary(pgls)$tTable[2,4],3))
pH<-ggplot(df, aes(time_from_bottleneck,y.res)) +
  geom_abline(intercept=pgls$coefficients[1],slope=pgls$coefficients[2],color="red",size=1) +
  geom_point(size=1.5,color=col) +
  theme_bw() + theme(axis.line=element_line(colour="black"),axis.text.x=element_text(size=10),axis.text.y=element_text(size=10)) +
  xlab("Time from Tetrapoda Bottleneck (My)") + ylab("") +
  annotate("text",x=100,y=0.8,label=test_text,hjust=0,size=3)

## Assortativity
variable<-"Assortativity"
y<-pectoral_subsample_parameters[,which(parameter_names==variable)]
x<-pelvic_subsample_parameters[,which(parameter_names==variable)]
# get residulas for the identity line
a=1;b=-1;c=0
xi = (b*(b*x-a*y)-a*c) / (a^2+b^2)
yi = (a*(-b*x+a*y)-b*c) / (a^2+b^2)
y.res<-abs(a*x+b*y+c)/sqrt(a^2+b^2)
y.res<-(y.res-min(y.res))/(max(y.res)-min(y.res)) # normalization (from 0 to 1)
# test fin-bearing vs limb-bearing taxa y.res
print(variable)
grp<-as.factor(c(rep(1,10),rep(2,4)))
names(y.res)<-names(grp)<-tre<-tree$tip.label 
aov.phylo(y.res~grp, tree)
# test residuals~time agree with bottleneck
df<-as.data.frame(cbind(y.res,time_from_bottleneck),row.names=tree$tip.label)
pgls<-gls(y.res[-14]~time_from_bottleneck[-14],df[-14,],corPagel(1,phy=drop.tip(tree,14)))
# plot result
test_text<-paste(variable,
                 "\n Ho: slope = 0",
                 "\n slope =",formatC(summary(pgls)$tTable[2,1],format="e",digits=2),
                 "\n SE =",formatC(summary(pgls)$tTable[2,2],format="e",digits=2),
                 "\n t =",formatC(summary(pgls)$tTable[2,2],format="e",digits=2),
                 "\n p-value =",round(summary(pgls)$tTable[2,4],3))
pA<-ggplot(df, aes(time_from_bottleneck,y.res)) +
  geom_abline(intercept=pgls$coefficients[1],slope=pgls$coefficients[2],color="red",size=1) +
  geom_point(size=1.5,color=col) +
  theme_bw() + theme(axis.line=element_line(colour="black"),axis.text.x=element_text(size=10),axis.text.y=element_text(size=10)) +
  xlab("Time from Tetrapoda Bottleneck (My)") + ylab("") +
  annotate("text",x=100,y=0.8,label=test_text,hjust=0,size=3)

## Parcellation
variable<-"Parcellation"
y<-pectoral_subsample_parameters[,which(parameter_names==variable)]
x<-pelvic_subsample_parameters[,which(parameter_names==variable)]
# get residulas for the identity line
a=1;b=-1;c=0
xi = (b*(b*x-a*y)-a*c) / (a^2+b^2)
yi = (a*(-b*x+a*y)-b*c) / (a^2+b^2)
y.res<-abs(a*x+b*y+c)/sqrt(a^2+b^2)
y.res<-(y.res-min(y.res))/(max(y.res)-min(y.res)) # normalization (from 0 to 1)
# test fin-bearing vs limb-bearing taxa y.res
print(variable)
grp<-as.factor(c(rep(1,10),rep(2,4)))
names(y.res)<-names(grp)<-tre<-tree$tip.label 
aov.phylo(y.res~grp, tree)
# test residuals~time agree with bottleneck
df<-as.data.frame(cbind(y.res,time_from_bottleneck),row.names=tree$tip.label)
pgls<-gls(y.res[-14]~time_from_bottleneck[-14],df[-14,],corPagel(1,phy=drop.tip(tree,14)))
# plot result
test_text<-paste(variable,
                 "\n Ho: slope = 0",
                 "\n slope =",formatC(summary(pgls)$tTable[2,1],format="e",digits=2),
                 "\n SE =",formatC(summary(pgls)$tTable[2,2],format="e",digits=2),
                 "\n t =",formatC(summary(pgls)$tTable[2,2],format="e",digits=2),
                 "\n p-value =",round(summary(pgls)$tTable[2,4],3))
pP<-ggplot(df, aes(time_from_bottleneck,y.res)) +
  geom_abline(intercept=pgls$coefficients[1],slope=pgls$coefficients[2],color="red",size=1) +
  geom_point(size=1.5,color=col) +
  theme_bw() + theme(axis.line=element_line(colour="black"),axis.text.x=element_text(size=10),axis.text.y=element_text(size=10),
                     axis.title.x = ) +
  xlab("Time from Tetrapoda Bottleneck (My)") + ylab("") +
  annotate("text",x=100,y=0.8,label=test_text,hjust=0,size=3)

# Plot all
svg(filename=paste("extended/Figure. Tetrapod bottleneck tests (extended).svg"),width=14,height=7)
grid.arrange(arrangeGrob(pN,pK,pD,pC,ncol=4), # first row, 2 columns
             arrangeGrob(pL,pH,pA,pP,ncol=4), # second row, 2 columns
             nrow=2)                    # number of rows
dev.off()

#############################################################################################################


